@@ -30,7 +30,7 @@ genBaseColStyle <- function(cc){
   }else if("3" %in% cc | "comma" %in% cc){
     colStyle$numFmt <- list("numFmtId" = "3")
     
-  }else if("numeric" %in% cc & !grepl("[^0\\.,#\\$\\* ]", getOption("openxlsx.numFmt", "GENERAL")) ){
+  }else if("numeric" %in% cc & !grepl("[^0\\.,#\\$\\* %]", getOption("openxlsx.numFmt", "GENERAL")) ){
     colStyle$numFmt <- list("numFmtId" = 9999, "formatCode" = getOption("openxlsx.numFmt"))
     
   }else{
@@ -49,7 +49,7 @@ genBaseColStyle <- function(cc){
 
 Workbook$methods(surroundingBorders = function(colClasses, sheet, startRow, startCol, nRow, nCol, borderColour, borderStyle, borderType){
   
-  sheet <- names(worksheets)[[validateSheet(sheet)]]
+  sheet <- sheet_names[[validateSheet(sheet)]]
   ## steps
   # get column class
   # get corresponding base style
@@ -366,7 +366,7 @@ Workbook$methods(surroundingBorders = function(colClasses, sheet, startRow, star
 
 Workbook$methods(rowBorders = function(colClasses, sheet, startRow, startCol, nRow, nCol, borderColour, borderStyle, borderType){
   
-  sheet <- names(worksheets)[[validateSheet(sheet)]]
+  sheet <- sheet_names[[validateSheet(sheet)]]
   ## steps
   # get column class
   # get corresponding base style
@@ -452,7 +452,7 @@ Workbook$methods(rowBorders = function(colClasses, sheet, startRow, startCol, nR
 
 Workbook$methods(columnBorders = function(colClasses, sheet, startRow, startCol, nRow, nCol, borderColour, borderStyle, borderType){
   
-  sheet <- names(worksheets)[[validateSheet(sheet)]]
+  sheet <- sheet_names[[validateSheet(sheet)]]
   ## steps
   # get column class
   # get corresponding base style
@@ -565,7 +565,7 @@ Workbook$methods(columnBorders = function(colClasses, sheet, startRow, startCol,
 
 Workbook$methods(allBorders = function(colClasses, sheet, startRow, startCol, nRow, nCol, borderColour, borderStyle, borderType){
   
-  sheet <- names(worksheets)[[sheet]]
+  sheet <- sheet_names[[validateSheet(sheet)]]
   ## steps
   # get column class
   # get corresponding base style
